# Changelog

## [0.5.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.4.0...v0.5.0) (2026-03-04)


### Features

* **pyproject:** add entry points for hardware components ([303804f](https://github.com/jbussdieker/bussdcc-hardware/commit/303804f25cc5ec4be0361108a89a07d326139000))

## [0.4.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.3.0...v0.4.0) (2026-03-03)


### Features

* **ds18b20:** add DS18B20 temperature sensor support ([f5c567b](https://github.com/jbussdieker/bussdcc-hardware/commit/f5c567b7aacf3d9eb92f156e3f04aae5c8f9c798))
* **usb_camera:** add support for USB camera integration ([a321d8a](https://github.com/jbussdieker/bussdcc-hardware/commit/a321d8a5fd34eef1d50ec74bffcbfa0d09eddd7d))

## [0.3.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.2.0...v0.3.0) (2026-03-03)


### Features

* **deps:** update bussdcc to version 0.28.0 ([423176c](https://github.com/jbussdieker/bussdcc-hardware/commit/423176cd9a5c4d90aa6acd27b086604d9d5fd46d))

## [0.2.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.1.0...v0.2.0) (2026-03-03)


### Features

* **pump:** add Pump device support ([2858dfb](https://github.com/jbussdieker/bussdcc-hardware/commit/2858dfb41426a8ecdd1394a5b6b2924b797944ce))

## 0.1.0 (2026-03-02)


### Features

* **i2c:** add I2CBus and NAU7802 device support ([12c78df](https://github.com/jbussdieker/bussdcc-hardware/commit/12c78dfcf0d715f4c2cc5aee57e03df285483f5a))
* initial commit ([01b3136](https://github.com/jbussdieker/bussdcc-hardware/commit/01b313647497bffa5c14babe7bb0801c9d082cf0))


### Documentation

* **readme:** expand README with project concepts ([ee73fc1](https://github.com/jbussdieker/bussdcc-hardware/commit/ee73fc17cbfd46a17021e3678108df9681922541))
